@@ -3,7 +3,7 @@ use Mojo::Base 'Mojolicious::Plugin';
 use Net::LDAP::SPNEGO;
 use IO::Socket::Timeout;
 use Mojo::Util qw(b64_decode);
-our $VERSION = '0.5.0';
+our $VERSION = '0.5.1';
 
 my %cCache;
 
@@ -44,16 +44,15 @@ sub register {
                         timeout=>$timeout,
                         verify => $cfg->{verify} // 'none'
                     ) or return 0;
-                    if ($cfg->{start_tls}){
-                        my $msg = $ldap->start_tls($cfg->{start_tls});
-                        if ($msg->is_error()){
-                            $c->log->error($msg->error);
-                            return 0;
+                    if ($ldap->uri !~ m{^ldaps://}){
+                        my $msg;
+                        if ($cfg->{verify})){
+                            $msg = $ldap->start_tls(verify => $cfg->{verify});
                         }
-                    }
-                    elsif ($ldap->uri !~ m{^ldaps://} and $cfg->{verify}){
-                        my $msg = $ldap->start_tls(verify => $cfg->{verify});
-                        if ($msg->is_error()){
+                        elsif ($cfg->{start_tls}){
+                            $msg = $ldap->start_tls($cfg->{start_tls});
+                        }
+                        if ($msg and $msg->is_error()){
                             $c->log->error($msg->error);
                             return 0;
                         }
